FEniCS Form Compiler 'X' documentation
======================================

The is an experimental version of the FEniCS Form Compiler.
It is developed at https://github.com/FEniCS/ffcx.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

API reference
=============

.. autosummary::
   :toctree: _autogenerated

   ffcx
   ffcx.__main__
   ffcx.analysis
   ffcx.compiler
   ffcx.element_interface
   ffcx.formatting
   ffcx.main
   ffcx.naming
   ffcx.codegeneration
   ffcx.options
   ffcx.ir.representation
   ffcx.ir.representationutils


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
